Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5)

Unified Diff: src/utils/SkTextureCompressor_Blitter.h

Issue 1316233002: Style Change: NULL->nullptr (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: 2015-08-27 (Thursday) 10:25:06 EDT Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/utils/SkTextureCompressor_ASTC.cpp ('k') | src/utils/SkTextureCompressor_LATC.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/utils/SkTextureCompressor_Blitter.h
diff --git a/src/utils/SkTextureCompressor_Blitter.h b/src/utils/SkTextureCompressor_Blitter.h
index e52237518f3b5840576739e7e6f3f124ed6769b4..0c259d692aa974831cb5118d8e15ba35d34d4709 100644
--- a/src/utils/SkTextureCompressor_Blitter.h
+++ b/src/utils/SkTextureCompressor_Blitter.h
@@ -366,10 +366,10 @@ public:
}
// If the blitter just sets a single value for each pixel, return the
// bitmap it draws into, and assign value. If not, return NULL and ignore
// the value parameter.
const SkPixmap* justAnOpaqueColor(uint32_t* value) override {
- return NULL;
+ return nullptr;
}
/**
« no previous file with comments | « src/utils/SkTextureCompressor_ASTC.cpp ('k') | src/utils/SkTextureCompressor_LATC.cpp » ('j') | no next file with comments »
@@ -366,10 +366,10 @@ public:
}
// If the blitter just sets a single value for each pixel, return the
- // bitmap it draws into, and assign value. If not, return NULL and ignore
+ // bitmap it draws into, and assign value. If not, return nullptr and ignore
// the value parameter.
const SkPixmap* justAnOpaqueColor(uint32_t* value) override {

Powered by Google App Engine
This is Rietveld 408576698